==> rocoecup-order-api-1.0-20140428.091243-55-sources.jar: com/rocoinfo/rocoecup/order/entity/OrderItem.java <==
/*******************************************************************************
 * Copyright (c) 2005, 2014 springside.github.io
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 *******************************************************************************/
package com.rocoinfo.rocoecup.order.entity;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang3.builder.ToStringBuilder;

import com.rocoinfo.rocoecup.entity.IdEntity;

public class OrderItem extends IdEntity {
	private static final long serialVersionUID = -1151208751615066138L;

	/**
	 * 所属订单
	 */
	private Long orderId;

	/**
	 * 各项单号
	 */
	private String orderNo;

	/**
	 * 商品
	 */
	private Long productId;

	/**
	 * 商品数量
	 */
	private Integer productQuantity;

	/**
	 * 商品SKU值
	 */
	private String sku;

	private List<Payment> payments = new ArrayList<Payment>();

	public OrderItem() {
	}

	public OrderItem(Long id) {
		this.id = id;
	}

	public Long getOrderId() {
		return orderId;
	}

	public void setOrderId(Long orderId) {
		this.orderId = orderId;
	}

	public String getOrderNo() {
		return orderNo;
	}

	public void setOrderNo(String orderNo) {
		this.orderNo = orderNo;
	}

	public Long getProductId() {
		return productId;
	}

	public void setProductId(Long productId) {
		this.productId = productId;
	}

	public Integer getProductQuantity() {
		return productQuantity;
	}

	public void setProductQuantity(Integer productQuantity) {
		this.productQuantity = productQuantity;
	}

	public String getSku() {
		return sku;
	}

	public void setSku(String sku) {
		this.sku = sku;
	}

	public List<Payment> getPayments() {
		return payments;
	}

	public void setPayments(List<Payment> payments) {
		this.payments = payments;
	}

	public void addPayment(Payment payment) {
		this.payments.add(payment);
	}

	@Override
	public String toString() {
		return ToStringBuilder.reflectionToString(this);
	}
}

==> rocoecup-order-api-1.0-20140430.070334-73-sources.jar: com/rocoinfo/rocoecup/order/entity/OrderItem.java <==
/*******************************************************************************
 * Copyright (c) 2005, 2014 springside.github.io
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 *******************************************************************************/
package com.rocoinfo.rocoecup.order.entity;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang3.builder.ToStringBuilder;

import com.rocoinfo.rocoecup.entity.IdEntity;

public class OrderItem extends IdEntity {
	private static final long serialVersionUID = -1151208751615066138L;

	/**
	 * 所属订单
	 */
	private Long orderId;

	/**
	 * 各项单号
	 */
	private String orderNo;

	/**
	 * 订单类型
	 */
	private Integer type;

	/**
	 * 商品
	 */
	private Long productId;

	/**
	 * 商品数量
	 */
	private Integer productQuantity;

	/**
	 * 商品SKU值
	 */
	private String sku;

	private List<Payment> payments = new ArrayList<Payment>();

	public OrderItem() {
	}

	public OrderItem(Long id) {
		this.id = id;
	}

	public Long getOrderId() {
		return orderId;
	}

	public void setOrderId(Long orderId) {
		this.orderId = orderId;
	}

	public String getOrderNo() {
		return orderNo;
	}

	public void setOrderNo(String orderNo) {
		this.orderNo = orderNo;
	}

	public Integer getType() {
		return type;
	}

	public void setType(Integer type) {
		this.type = type;
	}

	public Long getProductId() {
		return productId;
	}

	public void setProductId(Long productId) {
		this.productId = productId;
	}

	public Integer getProductQuantity() {
		return productQuantity;
	}

	public void setProductQuantity(Integer productQuantity) {
		this.productQuantity = productQuantity;
	}

	public String getSku() {
		return sku;
	}

	public void setSku(String sku) {
		this.sku = sku;
	}

	public List<Payment> getPayments() {
		return payments;
	}

	public void setPayments(List<Payment> payments) {
		this.payments = payments;
	}

	public void addPayment(Payment payment) {
		this.payments.add(payment);
	}

	@Override
	public String toString() {
		return ToStringBuilder.reflectionToString(this);
	}
}
